#!/bin/zsh

# Get the bunches folder path
strPath=$(./fetchFolderPath.sh)

# Initialise tag array
arrTags=()

# Loop through each available bunch file
for file in $strPath/**/*.bunch; do
	# Extract the tags from the file and add to the array
	tags=($(awk '/^tags:/ {for(i=2;i<=NF;i++) {gsub(/,/,"",$i); print $i}}' "$file"))
	arrTags+=($tags)
done

# Now we need to append front matter files for tags too
# In testing (2024-02-10), Bunch did not seem to recognise tags in folder.frontmatter.
# so I rasied this as a documentation issue on the Github repo to confirm - https://github.com/ttscoff/bunch/issues/321
# Loop through each available bunch file and add any tags they specify
for file in $strPath/**/*.frontmatter; do
	# Extract the tags from the file and add to the array
	tags=($(awk '/^tags:/ {for(i=2;i<=NF;i++) {gsub(/,/,"",$i); print $i}}' "$file"))
	arrTags+=($tags)
done

# Sort the array alphabetically and deduplicate tags
arrTags=($(echo "${arrTags[@]}" | tr ' ' '\n' | sort -u | tr '\n' ' '))

# Output the tags in a newline separated list
strTags=$(printf '%s\n' "${arrTags[@]}")
echo -n $strTags