#!/bin/zsh

# --------------------------------------------------
# This script must be passed a list of bunch names
# --------------------------------------------------
if [[ $# -eq 0 ]] ; then
	echo 'ERROR: This script must be passed a list of bunch names'
	exit 0
fi

# Get the Bunch app name to control (we may be using the beta app)
appname=$(./fetchAppname.sh)

# Get the path where the bunches are stored
strBunchPath=$(osascript -e "tell application \"$appname\" to get preference \"Folder\"" | sed 's/^file:\/\///')

# Generate an array of the bunches
arrTempBunches=(${(f)"$(echo $@)"})
# Sometimes temporary files can creep into Bunch's cache, so we will check bunches exist before including them.
arrBunches=()
bForceRefresh=0
for bunch in $arrTempBunches; do
	if [[ -e "$strBunchPath$bunch.bunch" ]]
	then
		arrBunches+=("$bunch")
	else
		# A bunch appears but does not exist, so Bunch need refreshing
		forceRefresh=1
	fi
	;
done

# If Bunch had phantom bunches we'll be a good citizen and push a forced refresh while we're here
if [[ $forceRefresh == 1 ]]
then
	./appForceRefresh.sh
fi

# Get a count of the bunches so we know when to stop outputting a comma in the JSON
intLastPos=$((${#arrBunches[*]}))

# Build the opening JSON
echo '{"items": ['

# Process each bunch as an entry in the JSON 'items' array
for bunch in $arrBunches; do
	echo -e '\t{'
	
	# Ouput simple properties
	echo -e "\t\t\"uid\": \"$bunch\","
	echo -e "\t\t\"arg\": \"$bunch\","
	echo -e "\t\t\"autocomplete\": \"$bunch\","
	
	# Output the title - there may be one specified in the bunch file
	strTitle=$(cat $strBunchPath$bunch.bunch | egrep "^title: " | sed "s/title: //")
	if [[ "$strTitle" == "" ]]
	then
		strTitle=$bunch # Default to bunch base file name if no title specified
	fi
	echo -e "\t\t\"title\": \"$strTitle\","
	
	# Output icon
	echo -e "\t\t\"icon\":"
	echo -e "\t\t{"
	echo -e "\t\t\t\"path\": \"./bunch.png\""
	echo -e "\t\t}"
	
	# If it is the last bunch, there's no trailing comma
	if [[ "$bunch" == "$arrBunches[$intLastPos]" ]]
	then
		echo -e "\t}"
	else
		echo -e "\t},"
	fi
	;
done

# Build the closing JSON
echo "]}"