#!/bin/zsh

# Get the Bunch app name to control (we may be using the beta app)
appname=$(./fetchAppname.sh)

# Get the path where the bunches are stored
strBunchPath=$(osascript -e "tell application \"$appname\" to get preference \"Folder\"" | sed 's/^file:\/\///')

# Get a list of open bunches - each bunch base file name on a new line
strOpenBunches=$(./fetchBunchesOpen.sh)

# Get a list of registered bunches - each bunch base file name on a new line
strAllBunches=$(./fetchBunches.sh)

# Generate arrays of the bunches
arrOpenBunches=(${(f)"$(echo $strOpenBunches)"})
arrAllBunches=(${(f)"$(echo $strAllBunches)"})

# Get a count of the bunches so we know when to stop outputting a comma in the JSON
intLastPos=$((${#arrBunches[*]}))

# Build the opening JSON
echo '{"items": ['

# Process each bunch as an entry in the JSON 'items' array
for bunch in $arrAllBunches; do
	echo -e '\t{'
	
	# Ouput simple properties
	echo -e "\t\t\"uid\": \"$bunch\","
	echo -e "\t\t\"arg\": \"$bunch\","
	echo -e "\t\t\"autocomplete\": \"$bunch\","
	
	# Output the title - there may be one specified in the bunch file
	strTitle=$(cat $strBunchPath$bunch.bunch | egrep "^title: " | sed "s/title: //")
	if [[ "$strTitle" == "" ]]
	then
		strTitle=$bunch # Default to bunch base file name if no title specified
	fi
	if (($arrOpenBunches[(Ie)$bunch]));
	then
		echo -e "\t\t\"title\": \"🟢 $strTitle\","
	else
		echo -e "\t\t\"title\": \"🔴 $strTitle\","
	fi
	
	# Output icon
	echo -e "\t\t\"icon\":"
	echo -e "\t\t{"
	echo -e "\t\t\t\"path\": \"./bunch.png\""
	echo -e "\t\t}"
	
	# If it is the last bunch, there's no trailing comma
	if [[ "$bunch" == "$arrBunches[$intLastPos]" ]]
	then
		echo -e "\t}"
	else
		echo -e "\t},"
	fi
	;
done

# Build the closing JSON
echo "]}"